/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SQL_ALLOCATE = 258,
     SQL_AUTOCOMMIT = 259,
     SQL_BOOL = 260,
     SQL_BREAK = 261,
     SQL_CALL = 262,
     SQL_CARDINALITY = 263,
     SQL_CONNECT = 264,
     SQL_COUNT = 265,
     SQL_DATETIME_INTERVAL_CODE = 266,
     SQL_DATETIME_INTERVAL_PRECISION = 267,
     SQL_DESCRIBE = 268,
     SQL_DESCRIPTOR = 269,
     SQL_DISCONNECT = 270,
     SQL_FOUND = 271,
     SQL_FREE = 272,
     SQL_GET = 273,
     SQL_GO = 274,
     SQL_GOTO = 275,
     SQL_IDENTIFIED = 276,
     SQL_INDICATOR = 277,
     SQL_KEY_MEMBER = 278,
     SQL_LENGTH = 279,
     SQL_LONG = 280,
     SQL_NULLABLE = 281,
     SQL_OCTET_LENGTH = 282,
     SQL_OPEN = 283,
     SQL_OUTPUT = 284,
     SQL_REFERENCE = 285,
     SQL_RETURNED_LENGTH = 286,
     SQL_RETURNED_OCTET_LENGTH = 287,
     SQL_SCALE = 288,
     SQL_SECTION = 289,
     SQL_SHORT = 290,
     SQL_SIGNED = 291,
     SQL_SQL = 292,
     SQL_SQLERROR = 293,
     SQL_SQLPRINT = 294,
     SQL_SQLWARNING = 295,
     SQL_START = 296,
     SQL_STOP = 297,
     SQL_STRUCT = 298,
     SQL_UNSIGNED = 299,
     SQL_VAR = 300,
     SQL_WHENEVER = 301,
     S_ADD = 302,
     S_AND = 303,
     S_ANYTHING = 304,
     S_AUTO = 305,
     S_CONST = 306,
     S_DEC = 307,
     S_DIV = 308,
     S_DOTPOINT = 309,
     S_EQUAL = 310,
     S_EXTERN = 311,
     S_INC = 312,
     S_LSHIFT = 313,
     S_MEMPOINT = 314,
     S_MEMBER = 315,
     S_MOD = 316,
     S_MUL = 317,
     S_NEQUAL = 318,
     S_OR = 319,
     S_REGISTER = 320,
     S_RSHIFT = 321,
     S_STATIC = 322,
     S_SUB = 323,
     S_VOLATILE = 324,
     S_TYPEDEF = 325,
     CSTRING = 326,
     CVARIABLE = 327,
     CPP_LINE = 328,
     IP = 329,
     DOLCONST = 330,
     ECONST = 331,
     NCONST = 332,
     UCONST = 333,
     UIDENT = 334,
     IDENT = 335,
     FCONST = 336,
     SCONST = 337,
     BCONST = 338,
     XCONST = 339,
     Op = 340,
     ICONST = 341,
     PARAM = 342,
     TYPECAST = 343,
     DOT_DOT = 344,
     COLON_EQUALS = 345,
     ABORT_P = 346,
     ABSOLUTE_P = 347,
     ACCESS = 348,
     ACTION = 349,
     ADD_P = 350,
     ADMIN = 351,
     AFTER = 352,
     AGGREGATE = 353,
     ALL = 354,
     ALSO = 355,
     ALTER = 356,
     ALWAYS = 357,
     ANALYSE = 358,
     ANALYZE = 359,
     AND = 360,
     ANY = 361,
     ARRAY = 362,
     AS = 363,
     ASC = 364,
     ASSERTION = 365,
     ASSIGNMENT = 366,
     ASYMMETRIC = 367,
     AT = 368,
     ATTRIBUTE = 369,
     AUTHORIZATION = 370,
     BACKWARD = 371,
     BEFORE = 372,
     BEGIN_P = 373,
     BETWEEN = 374,
     BIGINT = 375,
     BINARY = 376,
     BIT = 377,
     BOOLEAN_P = 378,
     BOTH = 379,
     BY = 380,
     CACHE = 381,
     CALLED = 382,
     CASCADE = 383,
     CASCADED = 384,
     CASE = 385,
     CAST = 386,
     CATALOG_P = 387,
     CHAIN = 388,
     CHAR_P = 389,
     CHARACTER = 390,
     CHARACTERISTICS = 391,
     CHECK = 392,
     CHECKPOINT = 393,
     CLASS = 394,
     CLOSE = 395,
     CLUSTER = 396,
     COALESCE = 397,
     COLLATE = 398,
     COLLATION = 399,
     COLUMN = 400,
     COMMENT = 401,
     COMMENTS = 402,
     COMMIT = 403,
     COMMITTED = 404,
     CONCURRENTLY = 405,
     CONFIGURATION = 406,
     CONNECTION = 407,
     CONSTRAINT = 408,
     CONSTRAINTS = 409,
     CONTENT_P = 410,
     CONTINUE_P = 411,
     CONVERSION_P = 412,
     COPY = 413,
     COST = 414,
     CREATE = 415,
     CROSS = 416,
     CSV = 417,
     CURRENT_P = 418,
     CURRENT_CATALOG = 419,
     CURRENT_DATE = 420,
     CURRENT_ROLE = 421,
     CURRENT_SCHEMA = 422,
     CURRENT_TIME = 423,
     CURRENT_TIMESTAMP = 424,
     CURRENT_USER = 425,
     CURSOR = 426,
     CYCLE = 427,
     DATA_P = 428,
     DATABASE = 429,
     DAY_P = 430,
     DEALLOCATE = 431,
     DEC = 432,
     DECIMAL_P = 433,
     DECLARE = 434,
     DEFAULT = 435,
     DEFAULTS = 436,
     DEFERRABLE = 437,
     DEFERRED = 438,
     DEFINER = 439,
     DELETE_P = 440,
     DELIMITER = 441,
     DELIMITERS = 442,
     DESC = 443,
     DICTIONARY = 444,
     DISABLE_P = 445,
     DISCARD = 446,
     DISTINCT = 447,
     DO = 448,
     DOCUMENT_P = 449,
     DOMAIN_P = 450,
     DOUBLE_P = 451,
     DROP = 452,
     EACH = 453,
     ELSE = 454,
     ENABLE_P = 455,
     ENCODING = 456,
     ENCRYPTED = 457,
     END_P = 458,
     ENUM_P = 459,
     ESCAPE = 460,
     EXCEPT = 461,
     EXCLUDE = 462,
     EXCLUDING = 463,
     EXCLUSIVE = 464,
     EXECUTE = 465,
     EXISTS = 466,
     EXPLAIN = 467,
     EXTENSION = 468,
     EXTERNAL = 469,
     EXTRACT = 470,
     FALSE_P = 471,
     FAMILY = 472,
     FETCH = 473,
     FIRST_P = 474,
     FLOAT_P = 475,
     FOLLOWING = 476,
     FOR = 477,
     FORCE = 478,
     FOREIGN = 479,
     FORWARD = 480,
     FREEZE = 481,
     FROM = 482,
     FULL = 483,
     FUNCTION = 484,
     FUNCTIONS = 485,
     GLOBAL = 486,
     GRANT = 487,
     GRANTED = 488,
     GREATEST = 489,
     GROUP_P = 490,
     HANDLER = 491,
     HAVING = 492,
     HEADER_P = 493,
     HOLD = 494,
     HOUR_P = 495,
     IDENTITY_P = 496,
     IF_P = 497,
     ILIKE = 498,
     IMMEDIATE = 499,
     IMMUTABLE = 500,
     IMPLICIT_P = 501,
     IN_P = 502,
     INCLUDING = 503,
     INCREMENT = 504,
     INDEX = 505,
     INDEXES = 506,
     INHERIT = 507,
     INHERITS = 508,
     INITIALLY = 509,
     INLINE_P = 510,
     INNER_P = 511,
     INOUT = 512,
     INPUT_P = 513,
     INSENSITIVE = 514,
     INSERT = 515,
     INSTEAD = 516,
     INT_P = 517,
     INTEGER = 518,
     INTERSECT = 519,
     INTERVAL = 520,
     INTO = 521,
     INVOKER = 522,
     IS = 523,
     ISNULL = 524,
     ISOLATION = 525,
     JOIN = 526,
     KEY = 527,
     LABEL = 528,
     LANGUAGE = 529,
     LARGE_P = 530,
     LAST_P = 531,
     LC_COLLATE_P = 532,
     LC_CTYPE_P = 533,
     LEADING = 534,
     LEAKPROOF = 535,
     LEAST = 536,
     LEFT = 537,
     LEVEL = 538,
     LIKE = 539,
     LIMIT = 540,
     LISTEN = 541,
     LOAD = 542,
     LOCAL = 543,
     LOCALTIME = 544,
     LOCALTIMESTAMP = 545,
     LOCATION = 546,
     LOCK_P = 547,
     MAPPING = 548,
     MATCH = 549,
     MAXVALUE = 550,
     MINUTE_P = 551,
     MINVALUE = 552,
     MODE = 553,
     MONTH_P = 554,
     MOVE = 555,
     NAME_P = 556,
     NAMES = 557,
     NATIONAL = 558,
     NATURAL = 559,
     NCHAR = 560,
     NEXT = 561,
     NO = 562,
     NONE = 563,
     NOT = 564,
     NOTHING = 565,
     NOTIFY = 566,
     NOTNULL = 567,
     NOWAIT = 568,
     NULL_P = 569,
     NULLIF = 570,
     NULLS_P = 571,
     NUMERIC = 572,
     OBJECT_P = 573,
     OF = 574,
     OFF = 575,
     OFFSET = 576,
     OIDS = 577,
     ON = 578,
     ONLY = 579,
     OPERATOR = 580,
     OPTION = 581,
     OPTIONS = 582,
     OR = 583,
     ORDER = 584,
     OUT_P = 585,
     OUTER_P = 586,
     OVER = 587,
     OVERLAPS = 588,
     OVERLAY = 589,
     OWNED = 590,
     OWNER = 591,
     PARSER = 592,
     PARTIAL = 593,
     PARTITION = 594,
     PASSING = 595,
     PASSWORD = 596,
     PLACING = 597,
     PLANS = 598,
     POSITION = 599,
     PRECEDING = 600,
     PRECISION = 601,
     PRESERVE = 602,
     PREPARE = 603,
     PREPARED = 604,
     PRIMARY = 605,
     PRIOR = 606,
     PRIVILEGES = 607,
     PROCEDURAL = 608,
     PROCEDURE = 609,
     QUOTE = 610,
     RANGE = 611,
     READ = 612,
     REAL = 613,
     REASSIGN = 614,
     RECHECK = 615,
     RECURSIVE = 616,
     REF = 617,
     REFERENCES = 618,
     REINDEX = 619,
     RELATIVE_P = 620,
     RELEASE = 621,
     RENAME = 622,
     REPEATABLE = 623,
     REPLACE = 624,
     REPLICA = 625,
     RESET = 626,
     RESTART = 627,
     RESTRICT = 628,
     RETURNING = 629,
     RETURNS = 630,
     REVOKE = 631,
     RIGHT = 632,
     ROLE = 633,
     ROLLBACK = 634,
     ROW = 635,
     ROWS = 636,
     RULE = 637,
     SAVEPOINT = 638,
     SCHEMA = 639,
     SCROLL = 640,
     SEARCH = 641,
     SECOND_P = 642,
     SECURITY = 643,
     SELECT = 644,
     SEQUENCE = 645,
     SEQUENCES = 646,
     SERIALIZABLE = 647,
     SERVER = 648,
     SESSION = 649,
     SESSION_USER = 650,
     SET = 651,
     SETOF = 652,
     SHARE = 653,
     SHOW = 654,
     SIMILAR = 655,
     SIMPLE = 656,
     SMALLINT = 657,
     SNAPSHOT = 658,
     SOME = 659,
     STABLE = 660,
     STANDALONE_P = 661,
     START = 662,
     STATEMENT = 663,
     STATISTICS = 664,
     STDIN = 665,
     STDOUT = 666,
     STORAGE = 667,
     STRICT_P = 668,
     STRIP_P = 669,
     SUBSTRING = 670,
     SYMMETRIC = 671,
     SYSID = 672,
     SYSTEM_P = 673,
     TABLE = 674,
     TABLES = 675,
     TABLESPACE = 676,
     TEMP = 677,
     TEMPLATE = 678,
     TEMPORARY = 679,
     TEXT_P = 680,
     THEN = 681,
     TIME = 682,
     TIMESTAMP = 683,
     TO = 684,
     TRAILING = 685,
     TRANSACTION = 686,
     TREAT = 687,
     TRIGGER = 688,
     TRIM = 689,
     TRUE_P = 690,
     TRUNCATE = 691,
     TRUSTED = 692,
     TYPE_P = 693,
     TYPES_P = 694,
     UNBOUNDED = 695,
     UNCOMMITTED = 696,
     UNENCRYPTED = 697,
     UNION = 698,
     UNIQUE = 699,
     UNKNOWN = 700,
     UNLISTEN = 701,
     UNLOGGED = 702,
     UNTIL = 703,
     UPDATE = 704,
     USER = 705,
     USING = 706,
     VACUUM = 707,
     VALID = 708,
     VALIDATE = 709,
     VALIDATOR = 710,
     VALUE_P = 711,
     VALUES = 712,
     VARCHAR = 713,
     VARIADIC = 714,
     VARYING = 715,
     VERBOSE = 716,
     VERSION_P = 717,
     VIEW = 718,
     VOLATILE = 719,
     WHEN = 720,
     WHERE = 721,
     WHITESPACE_P = 722,
     WINDOW = 723,
     WITH = 724,
     WITHOUT = 725,
     WORK = 726,
     WRAPPER = 727,
     WRITE = 728,
     XML_P = 729,
     XMLATTRIBUTES = 730,
     XMLCONCAT = 731,
     XMLELEMENT = 732,
     XMLEXISTS = 733,
     XMLFOREST = 734,
     XMLPARSE = 735,
     XMLPI = 736,
     XMLROOT = 737,
     XMLSERIALIZE = 738,
     YEAR_P = 739,
     YES_P = 740,
     ZONE = 741,
     NULLS_FIRST = 742,
     NULLS_LAST = 743,
     WITH_TIME = 744,
     POSTFIXOP = 745,
     UMINUS = 746
   };
#endif



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 564 "preproc.y"

	double	dval;
	char	*str;
	int		ival;
	struct	when		action;
	struct	index		index;
	int		tagname;
	struct	this_type	type;
	enum	ECPGttype	type_enum;
	enum	ECPGdtype	dtype_enum;
	struct	fetch_desc	descriptor;
	struct  su_symbol	struct_union;
	struct	prep		prep;



/* Line 2068 of yacc.c  */
#line 558 "preproc.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE base_yylval;

#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

extern YYLTYPE base_yylloc;

